Class: Sequence::Account
- Inherits:
-
ResponseObject
- Object
- ResponseObject
- Sequence::Account
- Defined in:
- lib/sequence/account.rb
Overview
A container that holds tokens in a ledger.
Defined Under Namespace
Classes: ClientModule, Key, Query
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
Unique identifier of the account.
-
#key_ids ⇒ Object
readonly
The list of IDs for the keys that control the account.
-
#quorum ⇒ Object
readonly
The number of keys required to sign transactions that transfer or retire tokens from the account.
-
#tags ⇒ Object
readonly
User-specified key-value data describing the account.
Method Summary
Methods inherited from ResponseObject
#[], #[]=, #initialize, #to_h, #to_json
Constructor Details
This class inherits a constructor from Sequence::ResponseObject
Instance Attribute Details
#id ⇒ Object (readonly)
Unique identifier of the account.
14 |
# File 'lib/sequence/account.rb', line 14 attrib :id |
#key_ids ⇒ Object (readonly)
The list of IDs for the keys that control the account.
19 |
# File 'lib/sequence/account.rb', line 19 attrib(:key_ids) |
#quorum ⇒ Object (readonly)
The number of keys required to sign transactions that transfer or retire tokens from the account.
25 |
# File 'lib/sequence/account.rb', line 25 attrib :quorum |
#tags ⇒ Object (readonly)
User-specified key-value data describing the account.
30 |
# File 'lib/sequence/account.rb', line 30 attrib :tags |