Class: Sequence::Token::Group
- Inherits:
-
ResponseObject
- Object
- ResponseObject
- Sequence::Token::Group
- Defined in:
- lib/sequence/token.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
readonly
The account containing the tokens.
-
#account_tags ⇒ Object
readonly
The tags of the account containing the tokens.
-
#amount ⇒ Object
readonly
The amount of tokens in the group.
-
#flavor_id ⇒ Object
readonly
The flavor of the tokens in the group.
-
#flavor_tags ⇒ Object
readonly
The tags of the flavor of the tokens in the group.
-
#tags ⇒ Object
readonly
The tags of the tokens in the group.
Method Summary
Methods inherited from ResponseObject
#[], #[]=, #initialize, #to_h, #to_json
Constructor Details
This class inherits a constructor from Sequence::ResponseObject
Instance Attribute Details
#account_id ⇒ Object (readonly)
The account containing the tokens.
77 |
# File 'lib/sequence/token.rb', line 77 attrib :account_id |
#account_tags ⇒ Object (readonly)
The tags of the account containing the tokens.
82 |
# File 'lib/sequence/token.rb', line 82 attrib :account_tags |
#amount ⇒ Object (readonly)
The amount of tokens in the group.
62 |
# File 'lib/sequence/token.rb', line 62 attrib :amount |
#flavor_id ⇒ Object (readonly)
The flavor of the tokens in the group.
67 |
# File 'lib/sequence/token.rb', line 67 attrib :flavor_id |
#flavor_tags ⇒ Object (readonly)
The tags of the flavor of the tokens in the group.
72 |
# File 'lib/sequence/token.rb', line 72 attrib :flavor_tags |
#tags ⇒ Object (readonly)
The tags of the tokens in the group.
87 |
# File 'lib/sequence/token.rb', line 87 attrib :tags |